@@ -19,7 +19,8 @@
 # c.flag_arg(flag_string) = returns the flag assignment for a "--option=argument" style flag
 #------------------------------------------------------------------------------------
 
-## TODO : add docstrings to library
+## TODO : help for each primary command
+## TODO: a yaml & json library module?
 # Application start
 def main():
     import sys
@@ -48,6 +49,9 @@ def main():
     # [ PRIMARY COMMAND LOGIC ]
     #   Test for primary commands and handle them
     #------------------------------------------------------------------------------------------
+    #------------------------------------------------------------------------------
+    # [ build ] - build the C code in the Naked library (2)= help
+    #------------------------------------------------------------------------------
     if c.cmd == "build":
         if c.cmd2 == "help":
             from Naked.commands.build import help as build_help
@@ -57,6 +61,22 @@ def main():
             import os, inspect
             abs_dirpath = os.path.join(os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))), "toolshed", "c")
             compile_c_code(abs_dirpath) # function calls exit status code
+    #------------------------------------------------------------------------------
+    # [ locate ] - locate Naked project files (2)= main, settings, setup
+    #------------------------------------------------------------------------------
+    elif c.cmd == "locate":
+        from Naked.commands.locate import Locator
+        if c.cmd2 == "main":
+            l = Locator('main')
+        elif c.cmd2 == "settings":
+            l = Locator('settings')
+        elif c.cmd2 == "setup":
+            l = Locator('setup')
+        else:
+            l = Locator('') #handles error report to user
+    #------------------------------------------------------------------------------
+    # [ make ] - make a new Naked project (args)=project name
+    #------------------------------------------------------------------------------
     elif c.cmd == "make":
         from Naked.commands.make import MakeController
         if c.arg1:
@@ -64,18 +84,23 @@ def main():
         else:
             m = MakeController(None)
         m.run()
+    #------------------------------------------------------------------------------
+    # [ test ] - Run tox tests on the project (2)= tox  (args)=py_version
+    #------------------------------------------------------------------------------
     elif c.cmd == "test":
-        from Naked.toolshed.ink import Template, Renderer
-        template = Template("This is a of the {{test}} of the {{document}} {{type}} and more of the {{test}} {{document}} {{type}}")
-        renderer = Renderer(template, {'test': 'ব য', 'document':'testing document', 'type':'of mine', 'bogus': 'bogus test'})
-        print(renderer.render())
-
-        #if c.option("-t"): c.truth = True
-        #print(c.truth)
+        if c.cmd2 == "tox":
+            from Naked.commands.test import ToxTester
+            if c.arg2: #user specified a python version to run with one of the tox version defs
+                t = ToxTester(c.arg2) #instantiate with the python version
+            else:
+                t = ToxTester()
+            t.run()
     elif c.cmd == "dl":
         from Naked.toolshed.network import HTTP
-        http = HTTP("https://github.com/chrissimpkins/six-four/tarball/master")
-        http.get_bin_write_file("test.tgz")
+        http = HTTP("http://www.google.com")
+        http.get()
+        response = http.response
+        print(response.status)
     elif c.cmd == "loc":
         from Naked.toolshed.system import cwd
         print(cwd())
